<?php

namespace Drupal\codit_menu_tools;

use Drupal\menu_link_content\Entity\MenuLinkContent;

/**
 * Class for inserting menu items into a menu.
 */
class MenuInsert extends MenuManipulatorBase implements MenuInsertInterface {

  /**
   * {@inheritdoc}
   */
  public function addMenuItem(
    string $item_title,
    string $item_destination,
    string $item_description = '',
    bool $enabled = TRUE,
    string $parent_title = '',
    string $sibling_title = '',
    bool $below = TRUE
  ): int {
    $this->preCheckRequiredItemValues($item_title, $item_destination);
    $parent_details = $this->findMenuItemDetailsByName($parent_title);
    $sibling_details = $this->findMenuItemDetailsByName($sibling_title, $parent_details['id']);
    $sibling_weight = $sibling_details['weight'] ?? 0;
    $item_weight = ($below) ? $sibling_weight + 1 : $sibling_weight - 1;
    // Using a redundant backup for parent. Most likely not needed.
    $parent_id = $sibling_details['parent_id'] ?? $parent_details['id'] ?? '';
    return MenuLinkContent::create([
      'title' => $item_title,
      'description' => $item_description,
      'link' => ['uri' => $item_destination],
      'menu_name' => $this->menuName,
      'enabled' => $enabled,
      'parent' => $parent_id,
      'weight' => $item_weight,
    ])->save();
  }

}
